@@ -130,69 +130,8 @@ def throttle[**Args, Result](
         # mimic function attributes if able
         return mimic_function(function, within=throttle)
 
-    if function := function:
+    if function is not None:
         return _wrap(function)
 
     else:
         return _wrap
-
-
-class _AsyncThrottle[**Args, Result]:
-    __slots__ = (
-        "__annotations__",
-        "__defaults__",
-        "__doc__",
-        "__globals__",
-        "__kwdefaults__",
-        "__name__",
-        "__qualname__",
-        "__wrapped__",
-        "_entries",
-        "_function",
-        "_limit",
-        "_lock",
-        "_period",
-    )
-
-    def __init__(
-        self,
-        function: Callable[Args, Coroutine[Any, Any, Result]],
-        /,
-        limit: int,
-        period: timedelta | float,
-    ) -> None:
-        self._function: Callable[Args, Coroutine[Any, Any, Result]] = function
-        self._entries: deque[float] = deque()
-        self._lock: Lock = Lock()
-        self._limit: int = limit
-        self._period: float
-        match period:
-            case timedelta() as delta:
-                self._period = delta.total_seconds()
-
-            case period_seconds:
-                self._period = period_seconds
-
-        # mimic function attributes if able
-        mimic_function(function, within=self)
-
-    async def __call__(
-        self,
-        *args: Args.args,
-        **kwargs: Args.kwargs,
-    ) -> Result:
-        async with self._lock:
-            time_now: float = monotonic()
-            while self._entries:  # cleanup old entries
-                if self._entries[0] + self._period <= time_now:
-                    self._entries.popleft()
-
-                else:
-                    break
-
-            if len(self._entries) >= self._limit:
-                await sleep(self._entries[0] - time_now)
-
-            self._entries.append(monotonic())
-
-        return await self._function(*args, **kwargs)
