@@ -1,9 +1,11 @@
 from haiway.postgres.client import PostgresConnectionPool
+from haiway.postgres.configuration import PostgresConfigurationRepository
 from haiway.postgres.state import Postgres, PostgresConnection
 from haiway.postgres.types import PostgresException, PostgresRow, PostgresValue
 
 __all__ = (
     "Postgres",
+    "PostgresConfigurationRepository",
     "PostgresConnection",
     "PostgresConnectionPool",
     "PostgresException",
